bayespy.inference.vmp.transformations.RotateGaussian.nodes
==========================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussian.nodes